@@ -30,10 +30,15 @@ Fashion
 Starve
 /;
 
-sub _random_nouns {
+sub _random_splice {
     my $n = shift;
-    my @n = @nouns;
-    return @n[0..($n-1)];
+    my $list = shift;
+    return splice @$list, 0, 2;
+}
+
+sub _random_nouns {
+    my $count = shift;
+    return @nouns[0..$count-1];
 }
 
 sub _random_verbs {
@@ -47,11 +52,13 @@ sub _random_pairs {
     return pairwise { "$a/$b" } @{[ _random_nouns($n) ]} , @{[ _random_verbs($n) ]};
 }
 
+my @copy = @nouns;
+
 plugin 'toto' => nav => [qw/this that theother/],
-  sidenav     => {
-    this     => [ _random_pairs(5), _random_nouns(3) ],
-    that     => [ _random_pairs(5), _random_nouns(3) ],
-    theother => [ _random_pairs(5), _random_nouns(3) ],
+  sidebar     => {
+    this     => [ _random_pairs(5), _random_splice(3,\@copy) ],
+    that     => [ _random_pairs(5), _random_splice(3,\@copy) ],
+    theother => [ _random_pairs(5), _random_splice(3,\@copy) ],
   },
   tabs => {
     $nouns[0] => [ _random_verbs(4) ],
